c ######################################################################
c #
c #                  BSCCO-2223 PROPERTIES PACKAGE
c #                  ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of BSCCO-2223
c #
c ######################################################################

c ######################################################################
      real function dBSCCO2223(T)
c ######################################################################
c #
c # Density of BSCCO-2223
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                  K
c #   dBSCCO2223      x      density                            kg/m**3
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dBSCCO2223 = 0.0
c *

      return
      end
c ######################################################################
      real function cBSCCO2223(T,B,Angle,Epslon)
c ######################################################################
c #
c # Specific heat of BSCCO-2223
c #
c # Range: Tmin <= T <= Tmax
c #
c #                        References
c #                        ----------
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                K
c #   B             x        magnetic field                      T
c #   Angle         x        field angle w/r to ab plane         degrees
c #   Epslon        x        strain                              -
c #   cBSCCO2223      x      specific heat                       J/Kg K
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,Angle,Epslon
c * fit variables

c * local variables

c *
      cBSCCO2223 = 0.0
c *
      return
      end
c ######################################################################
      real function kBSCCO2223(T)
c ######################################################################
c #
c # Thermal conductivity of BSCCO-2223
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                  K
c #   kBSCCO2223      x      thermal conductivity                W/m K
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      kBSCCO2223 = 0.0
c *

      return
      end
c ######################################################################
      real function rBSCCO2223(T)
c ######################################################################
c #
c # Electrical resistivity of BSCCO-2223
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                  K
c #   rBSCCO2223      x      resistivity                         Ohm m
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      rBSCCO2223 = 0.0
c *

      return
      end
c ######################################################################
      real function TcBSCCO2223(B,Angle,Epslon)
c ######################################################################
c #
c # Critical temperature, in K, for BSCCO-2223 as a function of applied
c # field
c #
c #                        References
c #                        ----------
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   B             x        magnetic field                      T
c #   Angle         x        field angle w/r to ab plane         degrees
c #   Epslon        x        strain                              -
c #   TcBSCCO2223     x      critical temperature                K
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Angle,Epslon
c * fit variables      

c * local variables

c *      
      TcBSCCO2223 = 0.0

c *
      return
      end
c ######################################################################
      real function BcBSCCO2223(T,Epslon)
c ######################################################################
c #
c # Upper critical field, in T, for BSCCO-2223 as a function of field
c #
c #                        References
c #                        ----------
c #
C # variable       I/O       meaning                             units
C # --------------------------------------------------------------------
C #   T            x         temperature                         K
c #   Epslon       x         strain                              -
c #   BcBSCCO2223    x       critical field                      T
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,Epslon
c * fit variables      

c * local variables

c *      
      BcBSCCO2223 = 0.0

c *
      return
      end
c ######################################################################
      real function JcBSCCO2223(T,B,Angle,Epslon)
c ######################################################################
c #
c # Critical (non-copper) current density, in A/m**2, for BSCCO-2223 as
c # a function of temperature and field. 
c #
c #                        References
c #                        ----------
c #
c #
C # variable       I/O       meaning                             units
C # --------------------------------------------------------------------
C #   T            x         temperature                         K
c #   B            x         magnetic field                      T
c #   Angle        x         field angle w/r to ab plane         degrees
c #   Epslon       x         strain                              -
c #   JcBSCCO2223    x       critical current density            A/m**2
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,B,Angle,Epslon
c * fit variables      

c * local variables

c *      
      JcBSCCO2223 = 0.0

c *
      return
      end
c ######################################################################
      real function TcsBSCCO2223(B,Angle,Epslon,Jop)
c ######################################################################
C #
C # Current sharing temperature, in K, for BSCCO-2223 as a function of 
c # field and operating current density.
C #
C # variable       I/O       meaning                             units
C # --------------------------------------------------------------------
C #   B            x         magnetic field                      T
c #   Angle        x         field angle w/r to ab plane         degrees
c #   Epslon       x         strain                              -
C #   Jop          x         operating current density           A/m**2
c #   TcsBSCCO2223   x       current sharing temperature         K
c #
c # Other functions called: 
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Angle,Epslon,Jop
c * fit variables      

c * local variables

c *      
      TcsBSCCO2223 = 0.0

c *
      return
      end
